@@ -38,6 +38,7 @@ from .common import get_sdk_headers
 # Service
 ##############################################################################
 
+
 class EnterpriseManagementV1(BaseService):
     """The Enterprise Management V1 service."""
 
@@ -45,23 +46,23 @@ class EnterpriseManagementV1(BaseService):
     DEFAULT_SERVICE_NAME = 'enterprise_management'
 
     @classmethod
-    def new_instance(cls,
-                     service_name: str = DEFAULT_SERVICE_NAME,
-                    ) -> 'EnterpriseManagementV1':
+    def new_instance(
+        cls,
+        service_name: str = DEFAULT_SERVICE_NAME,
+    ) -> 'EnterpriseManagementV1':
         """
         Return a new client for the Enterprise Management service using the
                specified parameters and external configuration.
         """
         authenticator = get_authenticator_from_environment(service_name)
-        service = cls(
-            authenticator
-            )
+        service = cls(authenticator)
         service.configure_service(service_name)
         return service
 
-    def __init__(self,
-                 authenticator: Authenticator = None,
-                ) -> None:
+    def __init__(
+        self,
+        authenticator: Authenticator = None,
+    ) -> None:
         """
         Construct a new client for the Enterprise Management service.
 
@@ -69,23 +70,14 @@ class EnterpriseManagementV1(BaseService):
                Get up to date information from https://github.com/IBM/python-sdk-core/blob/main/README.md
                about initializing the authenticator of your choice.
         """
-        BaseService.__init__(self,
-                             service_url=self.DEFAULT_SERVICE_URL,
-                             authenticator=authenticator)
-
+        BaseService.__init__(self, service_url=self.DEFAULT_SERVICE_URL, authenticator=authenticator)
 
     #########################
     # Enterprise Operations
     #########################
 
-
-    def create_enterprise(self,
-        source_account_id: str,
-        name: str,
-        primary_contact_iam_id: str,
-        *,
-        domain: str = None,
-        **kwargs
+    def create_enterprise(
+        self, source_account_id: str, name: str, primary_contact_iam_id: str, *, domain: str = None, **kwargs
     ) -> DetailedResponse:
         """
         Create an enterprise.
@@ -120,16 +112,16 @@ class EnterpriseManagementV1(BaseService):
         if primary_contact_iam_id is None:
             raise ValueError('primary_contact_iam_id must be provided')
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='create_enterprise')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='create_enterprise'
+        )
         headers.update(sdk_headers)
 
         data = {
             'source_account_id': source_account_id,
             'name': name,
             'primary_contact_iam_id': primary_contact_iam_id,
-            'domain': domain
+            'domain': domain,
         }
         data = {k: v for (k, v) in data.items() if v is not None}
         data = json.dumps(data)
@@ -141,23 +133,20 @@ class EnterpriseManagementV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/enterprises'
-        request = self.prepare_request(method='POST',
-                                       url=url,
-                                       headers=headers,
-                                       data=data)
+        request = self.prepare_request(method='POST', url=url, headers=headers, data=data)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def list_enterprises(self,
+    def list_enterprises(
+        self,
         *,
         enterprise_account_id: str = None,
         account_group_id: str = None,
         account_id: str = None,
         next_docid: str = None,
         limit: int = None,
-        **kwargs
+        **kwargs,
     ) -> DetailedResponse:
         """
         List enterprises.
@@ -192,9 +181,9 @@ class EnterpriseManagementV1(BaseService):
         """
 
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='list_enterprises')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='list_enterprises'
+        )
         headers.update(sdk_headers)
 
         params = {
@@ -202,7 +191,7 @@ class EnterpriseManagementV1(BaseService):
             'account_group_id': account_group_id,
             'account_id': account_id,
             'next_docid': next_docid,
-            'limit': limit
+            'limit': limit,
         }
 
         if 'headers' in kwargs:
@@ -211,19 +200,12 @@ class EnterpriseManagementV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/enterprises'
-        request = self.prepare_request(method='GET',
-                                       url=url,
-                                       headers=headers,
-                                       params=params)
+        request = self.prepare_request(method='GET', url=url, headers=headers, params=params)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def get_enterprise(self,
-        enterprise_id: str,
-        **kwargs
-    ) -> DetailedResponse:
+    def get_enterprise(self, enterprise_id: str, **kwargs) -> DetailedResponse:
         """
         Get enterprise by ID.
 
@@ -239,9 +221,9 @@ class EnterpriseManagementV1(BaseService):
         if not enterprise_id:
             raise ValueError('enterprise_id must be provided')
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='get_enterprise')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='get_enterprise'
+        )
         headers.update(sdk_headers)
 
         if 'headers' in kwargs:
@@ -253,21 +235,13 @@ class EnterpriseManagementV1(BaseService):
         path_param_values = self.encode_path_vars(enterprise_id)
         path_param_dict = dict(zip(path_param_keys, path_param_values))
         url = '/enterprises/{enterprise_id}'.format(**path_param_dict)
-        request = self.prepare_request(method='GET',
-                                       url=url,
-                                       headers=headers)
+        request = self.prepare_request(method='GET', url=url, headers=headers)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def update_enterprise(self,
-        enterprise_id: str,
-        *,
-        name: str = None,
-        domain: str = None,
-        primary_contact_iam_id: str = None,
-        **kwargs
+    def update_enterprise(
+        self, enterprise_id: str, *, name: str = None, domain: str = None, primary_contact_iam_id: str = None, **kwargs
     ) -> DetailedResponse:
         """
         Update an enterprise.
@@ -291,16 +265,12 @@ class EnterpriseManagementV1(BaseService):
         if not enterprise_id:
             raise ValueError('enterprise_id must be provided')
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='update_enterprise')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='update_enterprise'
+        )
         headers.update(sdk_headers)
 
-        data = {
-            'name': name,
-            'domain': domain,
-            'primary_contact_iam_id': primary_contact_iam_id
-        }
+        data = {'name': name, 'domain': domain, 'primary_contact_iam_id': primary_contact_iam_id}
         data = {k: v for (k, v) in data.items() if v is not None}
         data = json.dumps(data)
         headers['content-type'] = 'application/json'
@@ -313,10 +283,7 @@ class EnterpriseManagementV1(BaseService):
         path_param_values = self.encode_path_vars(enterprise_id)
         path_param_dict = dict(zip(path_param_keys, path_param_values))
         url = '/enterprises/{enterprise_id}'.format(**path_param_dict)
-        request = self.prepare_request(method='PATCH',
-                                       url=url,
-                                       headers=headers,
-                                       data=data)
+        request = self.prepare_request(method='PATCH', url=url, headers=headers, data=data)
 
         response = self.send(request, **kwargs)
         return response
@@ -325,14 +292,8 @@ class EnterpriseManagementV1(BaseService):
     # Account Operations
     #########################
 
-
-    def import_account_to_enterprise(self,
-        enterprise_id: str,
-        account_id: str,
-        *,
-        parent: str = None,
-        billing_unit_id: str = None,
-        **kwargs
+    def import_account_to_enterprise(
+        self, enterprise_id: str, account_id: str, *, parent: str = None, billing_unit_id: str = None, **kwargs
     ) -> DetailedResponse:
         """
         Import an account into an enterprise.
@@ -368,15 +329,12 @@ class EnterpriseManagementV1(BaseService):
         if not account_id:
             raise ValueError('account_id must be provided')
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='import_account_to_enterprise')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='import_account_to_enterprise'
+        )
         headers.update(sdk_headers)
 
-        data = {
-            'parent': parent,
-            'billing_unit_id': billing_unit_id
-        }
+        data = {'parent': parent, 'billing_unit_id': billing_unit_id}
         data = {k: v for (k, v) in data.items() if v is not None}
         data = json.dumps(data)
         headers['content-type'] = 'application/json'
@@ -389,21 +347,12 @@ class EnterpriseManagementV1(BaseService):
         path_param_values = self.encode_path_vars(enterprise_id, account_id)
         path_param_dict = dict(zip(path_param_keys, path_param_values))
         url = '/enterprises/{enterprise_id}/import/accounts/{account_id}'.format(**path_param_dict)
-        request = self.prepare_request(method='PUT',
-                                       url=url,
-                                       headers=headers,
-                                       data=data)
+        request = self.prepare_request(method='PUT', url=url, headers=headers, data=data)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def create_account(self,
-        parent: str,
-        name: str,
-        owner_iam_id: str,
-        **kwargs
-    ) -> DetailedResponse:
+    def create_account(self, parent: str, name: str, owner_iam_id: str, **kwargs) -> DetailedResponse:
         """
         Create a new account in an enterprise.
 
@@ -432,16 +381,12 @@ class EnterpriseManagementV1(BaseService):
         if owner_iam_id is None:
             raise ValueError('owner_iam_id must be provided')
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='create_account')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='create_account'
+        )
         headers.update(sdk_headers)
 
-        data = {
-            'parent': parent,
-            'name': name,
-            'owner_iam_id': owner_iam_id
-        }
+        data = {'parent': parent, 'name': name, 'owner_iam_id': owner_iam_id}
         data = {k: v for (k, v) in data.items() if v is not None}
         data = json.dumps(data)
         headers['content-type'] = 'application/json'
@@ -452,23 +397,20 @@ class EnterpriseManagementV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/accounts'
-        request = self.prepare_request(method='POST',
-                                       url=url,
-                                       headers=headers,
-                                       data=data)
+        request = self.prepare_request(method='POST', url=url, headers=headers, data=data)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def list_accounts(self,
+    def list_accounts(
+        self,
         *,
         enterprise_id: str = None,
         account_group_id: str = None,
         next_docid: str = None,
         parent: str = None,
         limit: int = None,
-        **kwargs
+        **kwargs,
     ) -> DetailedResponse:
         """
         List accounts.
@@ -506,9 +448,9 @@ class EnterpriseManagementV1(BaseService):
         """
 
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='list_accounts')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='list_accounts'
+        )
         headers.update(sdk_headers)
 
         params = {
@@ -516,7 +458,7 @@ class EnterpriseManagementV1(BaseService):
             'account_group_id': account_group_id,
             'next_docid': next_docid,
             'parent': parent,
-            'limit': limit
+            'limit': limit,
         }
 
         if 'headers' in kwargs:
@@ -525,19 +467,12 @@ class EnterpriseManagementV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/accounts'
-        request = self.prepare_request(method='GET',
-                                       url=url,
-                                       headers=headers,
-                                       params=params)
+        request = self.prepare_request(method='GET', url=url, headers=headers, params=params)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def get_account(self,
-        account_id: str,
-        **kwargs
-    ) -> DetailedResponse:
+    def get_account(self, account_id: str, **kwargs) -> DetailedResponse:
         """
         Get account by ID.
 
@@ -553,9 +488,9 @@ class EnterpriseManagementV1(BaseService):
         if not account_id:
             raise ValueError('account_id must be provided')
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='get_account')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='get_account'
+        )
         headers.update(sdk_headers)
 
         if 'headers' in kwargs:
@@ -567,19 +502,12 @@ class EnterpriseManagementV1(BaseService):
         path_param_values = self.encode_path_vars(account_id)
         path_param_dict = dict(zip(path_param_keys, path_param_values))
         url = '/accounts/{account_id}'.format(**path_param_dict)
-        request = self.prepare_request(method='GET',
-                                       url=url,
-                                       headers=headers)
+        request = self.prepare_request(method='GET', url=url, headers=headers)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def update_account(self,
-        account_id: str,
-        parent: str,
-        **kwargs
-    ) -> DetailedResponse:
+    def update_account(self, account_id: str, parent: str, **kwargs) -> DetailedResponse:
         """
         Move an account within the enterprise.
 
@@ -597,14 +525,12 @@ class EnterpriseManagementV1(BaseService):
         if parent is None:
             raise ValueError('parent must be provided')
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='update_account')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='update_account'
+        )
         headers.update(sdk_headers)
 
-        data = {
-            'parent': parent
-        }
+        data = {'parent': parent}
         data = {k: v for (k, v) in data.items() if v is not None}
         data = json.dumps(data)
         headers['content-type'] = 'application/json'
@@ -617,10 +543,7 @@ class EnterpriseManagementV1(BaseService):
         path_param_values = self.encode_path_vars(account_id)
         path_param_dict = dict(zip(path_param_keys, path_param_values))
         url = '/accounts/{account_id}'.format(**path_param_dict)
-        request = self.prepare_request(method='PATCH',
-                                       url=url,
-                                       headers=headers,
-                                       data=data)
+        request = self.prepare_request(method='PATCH', url=url, headers=headers, data=data)
 
         response = self.send(request, **kwargs)
         return response
@@ -629,13 +552,7 @@ class EnterpriseManagementV1(BaseService):
     # Account Group Operations
     #########################
 
-
-    def create_account_group(self,
-        parent: str,
-        name: str,
-        primary_contact_iam_id: str,
-        **kwargs
-    ) -> DetailedResponse:
+    def create_account_group(self, parent: str, name: str, primary_contact_iam_id: str, **kwargs) -> DetailedResponse:
         """
         Create an account group.
 
@@ -664,16 +581,12 @@ class EnterpriseManagementV1(BaseService):
         if primary_contact_iam_id is None:
             raise ValueError('primary_contact_iam_id must be provided')
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='create_account_group')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='create_account_group'
+        )
         headers.update(sdk_headers)
 
-        data = {
-            'parent': parent,
-            'name': name,
-            'primary_contact_iam_id': primary_contact_iam_id
-        }
+        data = {'parent': parent, 'name': name, 'primary_contact_iam_id': primary_contact_iam_id}
         data = {k: v for (k, v) in data.items() if v is not None}
         data = json.dumps(data)
         headers['content-type'] = 'application/json'
@@ -684,23 +597,20 @@ class EnterpriseManagementV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/account-groups'
-        request = self.prepare_request(method='POST',
-                                       url=url,
-                                       headers=headers,
-                                       data=data)
+        request = self.prepare_request(method='POST', url=url, headers=headers, data=data)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def list_account_groups(self,
+    def list_account_groups(
+        self,
         *,
         enterprise_id: str = None,
         parent_account_group_id: str = None,
         next_docid: str = None,
         parent: str = None,
         limit: int = None,
-        **kwargs
+        **kwargs,
     ) -> DetailedResponse:
         """
         List account groups.
@@ -740,9 +650,9 @@ class EnterpriseManagementV1(BaseService):
         """
 
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='list_account_groups')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='list_account_groups'
+        )
         headers.update(sdk_headers)
 
         params = {
@@ -750,7 +660,7 @@ class EnterpriseManagementV1(BaseService):
             'parent_account_group_id': parent_account_group_id,
             'next_docid': next_docid,
             'parent': parent,
-            'limit': limit
+            'limit': limit,
         }
 
         if 'headers' in kwargs:
@@ -759,19 +669,12 @@ class EnterpriseManagementV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/account-groups'
-        request = self.prepare_request(method='GET',
-                                       url=url,
-                                       headers=headers,
-                                       params=params)
+        request = self.prepare_request(method='GET', url=url, headers=headers, params=params)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def get_account_group(self,
-        account_group_id: str,
-        **kwargs
-    ) -> DetailedResponse:
+    def get_account_group(self, account_group_id: str, **kwargs) -> DetailedResponse:
         """
         Get account group by ID.
 
@@ -788,9 +691,9 @@ class EnterpriseManagementV1(BaseService):
         if not account_group_id:
             raise ValueError('account_group_id must be provided')
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='get_account_group')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='get_account_group'
+        )
         headers.update(sdk_headers)
 
         if 'headers' in kwargs:
@@ -802,20 +705,13 @@ class EnterpriseManagementV1(BaseService):
         path_param_values = self.encode_path_vars(account_group_id)
         path_param_dict = dict(zip(path_param_keys, path_param_values))
         url = '/account-groups/{account_group_id}'.format(**path_param_dict)
-        request = self.prepare_request(method='GET',
-                                       url=url,
-                                       headers=headers)
+        request = self.prepare_request(method='GET', url=url, headers=headers)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def update_account_group(self,
-        account_group_id: str,
-        *,
-        name: str = None,
-        primary_contact_iam_id: str = None,
-        **kwargs
+    def update_account_group(
+        self, account_group_id: str, *, name: str = None, primary_contact_iam_id: str = None, **kwargs
     ) -> DetailedResponse:
         """
         Update an account group.
@@ -836,15 +732,12 @@ class EnterpriseManagementV1(BaseService):
         if not account_group_id:
             raise ValueError('account_group_id must be provided')
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='update_account_group')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='update_account_group'
+        )
         headers.update(sdk_headers)
 
-        data = {
-            'name': name,
-            'primary_contact_iam_id': primary_contact_iam_id
-        }
+        data = {'name': name, 'primary_contact_iam_id': primary_contact_iam_id}
         data = {k: v for (k, v) in data.items() if v is not None}
         data = json.dumps(data)
         headers['content-type'] = 'application/json'
@@ -857,10 +750,7 @@ class EnterpriseManagementV1(BaseService):
         path_param_values = self.encode_path_vars(account_group_id)
         path_param_dict = dict(zip(path_param_keys, path_param_values))
         url = '/account-groups/{account_group_id}'.format(**path_param_dict)
-        request = self.prepare_request(method='PATCH',
-                                       url=url,
-                                       headers=headers,
-                                       data=data)
+        request = self.prepare_request(method='PATCH', url=url, headers=headers, data=data)
 
         response = self.send(request, **kwargs)
         return response
@@ -871,7 +761,7 @@ class EnterpriseManagementV1(BaseService):
 ##############################################################################
 
 
-class Account():
+class Account:
     """
     An account resource.
 
@@ -901,25 +791,27 @@ class Account():
           the account.
     """
 
-    def __init__(self,
-                 *,
-                 url: str = None,
-                 id: str = None,
-                 crn: str = None,
-                 parent: str = None,
-                 enterprise_account_id: str = None,
-                 enterprise_id: str = None,
-                 enterprise_path: str = None,
-                 name: str = None,
-                 state: str = None,
-                 owner_iam_id: str = None,
-                 paid: bool = None,
-                 owner_email: str = None,
-                 is_enterprise_account: bool = None,
-                 created_at: datetime = None,
-                 created_by: str = None,
-                 updated_at: datetime = None,
-                 updated_by: str = None) -> None:
+    def __init__(
+        self,
+        *,
+        url: str = None,
+        id: str = None,
+        crn: str = None,
+        parent: str = None,
+        enterprise_account_id: str = None,
+        enterprise_id: str = None,
+        enterprise_path: str = None,
+        name: str = None,
+        state: str = None,
+        owner_iam_id: str = None,
+        paid: bool = None,
+        owner_email: str = None,
+        is_enterprise_account: bool = None,
+        created_at: datetime = None,
+        created_by: str = None,
+        updated_at: datetime = None,
+        updated_by: str = None,
+    ) -> None:
         """
         Initialize a Account object.
 
@@ -1070,7 +962,8 @@ class Account():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class AccountGroup():
+
+class AccountGroup:
     """
     An account group resource.
 
@@ -1099,23 +992,25 @@ class AccountGroup():
           the account group.
     """
 
-    def __init__(self,
-                 *,
-                 url: str = None,
-                 id: str = None,
-                 crn: str = None,
-                 parent: str = None,
-                 enterprise_account_id: str = None,
-                 enterprise_id: str = None,
-                 enterprise_path: str = None,
-                 name: str = None,
-                 state: str = None,
-                 primary_contact_iam_id: str = None,
-                 primary_contact_email: str = None,
-                 created_at: datetime = None,
-                 created_by: str = None,
-                 updated_at: datetime = None,
-                 updated_by: str = None) -> None:
+    def __init__(
+        self,
+        *,
+        url: str = None,
+        id: str = None,
+        crn: str = None,
+        parent: str = None,
+        enterprise_account_id: str = None,
+        enterprise_id: str = None,
+        enterprise_path: str = None,
+        name: str = None,
+        state: str = None,
+        primary_contact_iam_id: str = None,
+        primary_contact_email: str = None,
+        created_at: datetime = None,
+        created_by: str = None,
+        updated_at: datetime = None,
+        updated_by: str = None,
+    ) -> None:
         """
         Initialize a AccountGroup object.
 
@@ -1254,7 +1149,8 @@ class AccountGroup():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class CreateAccountGroupResponse():
+
+class CreateAccountGroupResponse:
     """
     A newly-created account group.
 
@@ -1262,9 +1158,7 @@ class CreateAccountGroupResponse():
           was created.
     """
 
-    def __init__(self,
-                 *,
-                 account_group_id: str = None) -> None:
+    def __init__(self, *, account_group_id: str = None) -> None:
         """
         Initialize a CreateAccountGroupResponse object.
 
@@ -1311,16 +1205,15 @@ class CreateAccountGroupResponse():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class CreateAccountResponse():
+
+class CreateAccountResponse:
     """
     A newly-created account.
 
     :attr str account_id: (optional) The ID of the account entity that was created.
     """
 
-    def __init__(self,
-                 *,
-                 account_id: str = None) -> None:
+    def __init__(self, *, account_id: str = None) -> None:
         """
         Initialize a CreateAccountResponse object.
 
@@ -1367,7 +1260,8 @@ class CreateAccountResponse():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class CreateEnterpriseResponse():
+
+class CreateEnterpriseResponse:
     """
     The response from calling create enterprise.
 
@@ -1378,10 +1272,7 @@ class CreateEnterpriseResponse():
           the enterprise management.
     """
 
-    def __init__(self,
-                 *,
-                 enterprise_id: str = None,
-                 enterprise_account_id: str = None) -> None:
+    def __init__(self, *, enterprise_id: str = None, enterprise_account_id: str = None) -> None:
         """
         Initialize a CreateEnterpriseResponse object.
 
@@ -1436,7 +1327,8 @@ class CreateEnterpriseResponse():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class Enterprise():
+
+class Enterprise:
     """
     An enterprise resource.
 
@@ -1461,21 +1353,23 @@ class Enterprise():
           the enterprise.
     """
 
-    def __init__(self,
-                 *,
-                 url: str = None,
-                 id: str = None,
-                 enterprise_account_id: str = None,
-                 crn: str = None,
-                 name: str = None,
-                 domain: str = None,
-                 state: str = None,
-                 primary_contact_iam_id: str = None,
-                 primary_contact_email: str = None,
-                 created_at: datetime = None,
-                 created_by: str = None,
-                 updated_at: datetime = None,
-                 updated_by: str = None) -> None:
+    def __init__(
+        self,
+        *,
+        url: str = None,
+        id: str = None,
+        enterprise_account_id: str = None,
+        crn: str = None,
+        name: str = None,
+        domain: str = None,
+        state: str = None,
+        primary_contact_iam_id: str = None,
+        primary_contact_email: str = None,
+        created_at: datetime = None,
+        created_by: str = None,
+        updated_at: datetime = None,
+        updated_by: str = None,
+    ) -> None:
         """
         Initialize a Enterprise object.
 
@@ -1599,7 +1493,8 @@ class Enterprise():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class ListAccountGroupsResponse():
+
+class ListAccountGroupsResponse:
     """
     The list_account_groups operation response.
 
@@ -1610,11 +1505,7 @@ class ListAccountGroupsResponse():
     :attr List[AccountGroup] resources: (optional) A list of account groups.
     """
 
-    def __init__(self,
-                 *,
-                 rows_count: int = None,
-                 next_url: str = None,
-                 resources: List['AccountGroup'] = None) -> None:
+    def __init__(self, *, rows_count: int = None, next_url: str = None, resources: List['AccountGroup'] = None) -> None:
         """
         Initialize a ListAccountGroupsResponse object.
 
@@ -1680,7 +1571,8 @@ class ListAccountGroupsResponse():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class ListAccountsResponse():
+
+class ListAccountsResponse:
     """
     The list_accounts operation response.
 
@@ -1691,11 +1583,7 @@ class ListAccountsResponse():
     :attr List[Account] resources: (optional) A list of accounts.
     """
 
-    def __init__(self,
-                 *,
-                 rows_count: int = None,
-                 next_url: str = None,
-                 resources: List['Account'] = None) -> None:
+    def __init__(self, *, rows_count: int = None, next_url: str = None, resources: List['Account'] = None) -> None:
         """
         Initialize a ListAccountsResponse object.
 
@@ -1761,7 +1649,8 @@ class ListAccountsResponse():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class ListEnterprisesResponse():
+
+class ListEnterprisesResponse:
     """
     The response from calling list enterprises.
 
@@ -1772,11 +1661,7 @@ class ListEnterprisesResponse():
     :attr List[Enterprise] resources: (optional) A list of enterprise objects.
     """
 
-    def __init__(self,
-                 *,
-                 rows_count: int = None,
-                 next_url: str = None,
-                 resources: List['Enterprise'] = None) -> None:
+    def __init__(self, *, rows_count: int = None, next_url: str = None, resources: List['Enterprise'] = None) -> None:
         """
         Initialize a ListEnterprisesResponse object.
 
@@ -1842,22 +1727,25 @@ class ListEnterprisesResponse():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
+
 ##############################################################################
 # Pagers
 ##############################################################################
 
-class EnterprisesPager():
+
+class EnterprisesPager:
     """
     EnterprisesPager can be used to simplify the use of the "list_enterprises" method.
     """
 
-    def __init__(self,
-                 *,
-                 client: EnterpriseManagementV1,
-                 enterprise_account_id: str = None,
-                 account_group_id: str = None,
-                 account_id: str = None,
-                 limit: int = None,
+    def __init__(
+        self,
+        *,
+        client: EnterpriseManagementV1,
+        enterprise_account_id: str = None,
+        account_group_id: str = None,
+        account_id: str = None,
+        limit: int = None,
     ) -> None:
         """
         Initialize a EnterprisesPager object.
@@ -1871,7 +1759,7 @@ class EnterprisesPager():
         """
         self._has_next = True
         self._client = client
-        self._page_context = { 'next': None }
+        self._page_context = {'next': None}
         self._enterprise_account_id = enterprise_account_id
         self._account_group_id = account_group_id
         self._account_id = account_id
@@ -1923,18 +1811,20 @@ class EnterprisesPager():
             results.extend(next_page)
         return results
 
-class AccountsPager():
+
+class AccountsPager:
     """
     AccountsPager can be used to simplify the use of the "list_accounts" method.
     """
 
-    def __init__(self,
-                 *,
-                 client: EnterpriseManagementV1,
-                 enterprise_id: str = None,
-                 account_group_id: str = None,
-                 parent: str = None,
-                 limit: int = None,
+    def __init__(
+        self,
+        *,
+        client: EnterpriseManagementV1,
+        enterprise_id: str = None,
+        account_group_id: str = None,
+        parent: str = None,
+        limit: int = None,
     ) -> None:
         """
         Initialize a AccountsPager object.
@@ -1950,7 +1840,7 @@ class AccountsPager():
         """
         self._has_next = True
         self._client = client
-        self._page_context = { 'next': None }
+        self._page_context = {'next': None}
         self._enterprise_id = enterprise_id
         self._account_group_id = account_group_id
         self._parent = parent
@@ -2002,18 +1892,20 @@ class AccountsPager():
             results.extend(next_page)
         return results
 
-class AccountGroupsPager():
+
+class AccountGroupsPager:
     """
     AccountGroupsPager can be used to simplify the use of the "list_account_groups" method.
     """
 
-    def __init__(self,
-                 *,
-                 client: EnterpriseManagementV1,
-                 enterprise_id: str = None,
-                 parent_account_group_id: str = None,
-                 parent: str = None,
-                 limit: int = None,
+    def __init__(
+        self,
+        *,
+        client: EnterpriseManagementV1,
+        enterprise_id: str = None,
+        parent_account_group_id: str = None,
+        parent: str = None,
+        limit: int = None,
     ) -> None:
         """
         Initialize a AccountGroupsPager object.
@@ -2030,7 +1922,7 @@ class AccountGroupsPager():
         """
         self._has_next = True
         self._client = client
-        self._page_context = { 'next': None }
+        self._page_context = {'next': None}
         self._enterprise_id = enterprise_id
         self._parent_account_group_id = parent_account_group_id
         self._parent = parent
