@@ -42,6 +42,7 @@ from .common import get_sdk_headers
 # Service
 ##############################################################################
 
+
 class GlobalTaggingV1(BaseService):
     """The global_tagging V1 service."""
 
@@ -49,23 +50,23 @@ class GlobalTaggingV1(BaseService):
     DEFAULT_SERVICE_NAME = 'global_tagging'
 
     @classmethod
-    def new_instance(cls,
-                     service_name: str = DEFAULT_SERVICE_NAME,
-                    ) -> 'GlobalTaggingV1':
+    def new_instance(
+        cls,
+        service_name: str = DEFAULT_SERVICE_NAME,
+    ) -> 'GlobalTaggingV1':
         """
         Return a new client for the global_tagging service using the specified
                parameters and external configuration.
         """
         authenticator = get_authenticator_from_environment(service_name)
-        service = cls(
-            authenticator
-            )
+        service = cls(authenticator)
         service.configure_service(service_name)
         return service
 
-    def __init__(self,
-                 authenticator: Authenticator = None,
-                ) -> None:
+    def __init__(
+        self,
+        authenticator: Authenticator = None,
+    ) -> None:
         """
         Construct a new client for the global_tagging service.
 
@@ -73,17 +74,14 @@ class GlobalTaggingV1(BaseService):
                Get up to date information from https://github.com/IBM/python-sdk-core/blob/master/README.md
                about initializing the authenticator of your choice.
         """
-        BaseService.__init__(self,
-                             service_url=self.DEFAULT_SERVICE_URL,
-                             authenticator=authenticator)
-
+        BaseService.__init__(self, service_url=self.DEFAULT_SERVICE_URL, authenticator=authenticator)
 
     #########################
     # tags
     #########################
 
-
-    def list_tags(self,
+    def list_tags(
+        self,
         *,
         impersonate_user: str = None,
         account_id: str = None,
@@ -141,9 +139,9 @@ class GlobalTaggingV1(BaseService):
         """
 
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='list_tags')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='list_tags'
+        )
         headers.update(sdk_headers)
 
         params = {
@@ -157,7 +155,7 @@ class GlobalTaggingV1(BaseService):
             'limit': limit,
             'timeout': timeout,
             'order_by_name': order_by_name,
-            'attached_only': attached_only
+            'attached_only': attached_only,
         }
 
         if 'headers' in kwargs:
@@ -165,16 +163,13 @@ class GlobalTaggingV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/v3/tags'
-        request = self.prepare_request(method='GET',
-                                       url=url,
-                                       headers=headers,
-                                       params=params)
+        request = self.prepare_request(method='GET', url=url, headers=headers, params=params)
 
         response = self.send(request)
         return response
 
-
-    def create_tag(self,
+    def create_tag(
+        self,
         tag_names: List[str],
         *,
         impersonate_user: str = None,
@@ -207,20 +202,14 @@ class GlobalTaggingV1(BaseService):
         if tag_names is None:
             raise ValueError('tag_names must be provided')
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='create_tag')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='create_tag'
+        )
         headers.update(sdk_headers)
 
-        params = {
-            'impersonate_user': impersonate_user,
-            'account_id': account_id,
-            'tag_type': tag_type
-        }
+        params = {'impersonate_user': impersonate_user, 'account_id': account_id, 'tag_type': tag_type}
 
-        data = {
-            'tag_names': tag_names
-        }
+        data = {'tag_names': tag_names}
         data = {k: v for (k, v) in data.items() if v is not None}
         data = json.dumps(data)
         headers['content-type'] = 'application/json'
@@ -230,17 +219,13 @@ class GlobalTaggingV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/v3/tags'
-        request = self.prepare_request(method='POST',
-                                       url=url,
-                                       headers=headers,
-                                       params=params,
-                                       data=data)
+        request = self.prepare_request(method='POST', url=url, headers=headers, params=params, data=data)
 
         response = self.send(request)
         return response
 
-
-    def delete_tag_all(self,
+    def delete_tag_all(
+        self,
         *,
         providers: str = None,
         impersonate_user: str = None,
@@ -269,16 +254,16 @@ class GlobalTaggingV1(BaseService):
         """
 
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='delete_tag_all')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='delete_tag_all'
+        )
         headers.update(sdk_headers)
 
         params = {
             'providers': providers,
             'impersonate_user': impersonate_user,
             'account_id': account_id,
-            'tag_type': tag_type
+            'tag_type': tag_type,
         }
 
         if 'headers' in kwargs:
@@ -286,16 +271,13 @@ class GlobalTaggingV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/v3/tags'
-        request = self.prepare_request(method='DELETE',
-                                       url=url,
-                                       headers=headers,
-                                       params=params)
+        request = self.prepare_request(method='DELETE', url=url, headers=headers, params=params)
 
         response = self.send(request)
         return response
 
-
-    def delete_tag(self,
+    def delete_tag(
+        self,
         tag_name: str,
         *,
         providers: List[str] = None,
@@ -330,16 +312,16 @@ class GlobalTaggingV1(BaseService):
         if tag_name is None:
             raise ValueError('tag_name must be provided')
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='delete_tag')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='delete_tag'
+        )
         headers.update(sdk_headers)
 
         params = {
             'providers': convert_list(providers),
             'impersonate_user': impersonate_user,
             'account_id': account_id,
-            'tag_type': tag_type
+            'tag_type': tag_type,
         }
 
         if 'headers' in kwargs:
@@ -350,16 +332,13 @@ class GlobalTaggingV1(BaseService):
         path_param_values = self.encode_path_vars(tag_name)
         path_param_dict = dict(zip(path_param_keys, path_param_values))
         url = '/v3/tags/{tag_name}'.format(**path_param_dict)
-        request = self.prepare_request(method='DELETE',
-                                       url=url,
-                                       headers=headers,
-                                       params=params)
+        request = self.prepare_request(method='DELETE', url=url, headers=headers, params=params)
 
         response = self.send(request)
         return response
 
-
-    def attach_tag(self,
+    def attach_tag(
+        self,
         resources: List['Resource'],
         *,
         tag_name: str = None,
@@ -396,22 +375,14 @@ class GlobalTaggingV1(BaseService):
             raise ValueError('resources must be provided')
         resources = [convert_model(x) for x in resources]
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='attach_tag')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='attach_tag'
+        )
         headers.update(sdk_headers)
 
-        params = {
-            'impersonate_user': impersonate_user,
-            'account_id': account_id,
-            'tag_type': tag_type
-        }
+        params = {'impersonate_user': impersonate_user, 'account_id': account_id, 'tag_type': tag_type}
 
-        data = {
-            'resources': resources,
-            'tag_name': tag_name,
-            'tag_names': tag_names
-        }
+        data = {'resources': resources, 'tag_name': tag_name, 'tag_names': tag_names}
         data = {k: v for (k, v) in data.items() if v is not None}
         data = json.dumps(data)
         headers['content-type'] = 'application/json'
@@ -421,17 +392,13 @@ class GlobalTaggingV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/v3/tags/attach'
-        request = self.prepare_request(method='POST',
-                                       url=url,
-                                       headers=headers,
-                                       params=params,
-                                       data=data)
+        request = self.prepare_request(method='POST', url=url, headers=headers, params=params, data=data)
 
         response = self.send(request)
         return response
 
-
-    def detach_tag(self,
+    def detach_tag(
+        self,
         resources: List['Resource'],
         *,
         tag_name: str = None,
@@ -468,22 +435,14 @@ class GlobalTaggingV1(BaseService):
             raise ValueError('resources must be provided')
         resources = [convert_model(x) for x in resources]
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='detach_tag')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='detach_tag'
+        )
         headers.update(sdk_headers)
 
-        params = {
-            'impersonate_user': impersonate_user,
-            'account_id': account_id,
-            'tag_type': tag_type
-        }
+        params = {'impersonate_user': impersonate_user, 'account_id': account_id, 'tag_type': tag_type}
 
-        data = {
-            'resources': resources,
-            'tag_name': tag_name,
-            'tag_names': tag_names
-        }
+        data = {'resources': resources, 'tag_name': tag_name, 'tag_names': tag_names}
         data = {k: v for (k, v) in data.items() if v is not None}
         data = json.dumps(data)
         headers['content-type'] = 'application/json'
@@ -493,11 +452,7 @@ class GlobalTaggingV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/v3/tags/detach'
-        request = self.prepare_request(method='POST',
-                                       url=url,
-                                       headers=headers,
-                                       params=params,
-                                       data=data)
+        request = self.prepare_request(method='POST', url=url, headers=headers, params=params, data=data)
 
         response = self.send(request)
         return response
@@ -513,9 +468,11 @@ class ListTagsEnums:
         The type of the tag you want to list. Supported values are `user`, `service` and
         `access`.
         """
+
         USER = 'user'
         SERVICE = 'service'
         ACCESS = 'access'
+
     class Providers(str, Enum):
         """
         Select a provider. Supported values are `ghost` and `ims`. To list both Global
@@ -523,12 +480,15 @@ class ListTagsEnums:
         `access` tags can only be attached to resources that are onboarded to Global
         Search and Tagging, so you should not set this parameter when listing them.
         """
+
         GHOST = 'ghost'
         IMS = 'ims'
+
     class OrderByName(str, Enum):
         """
         Order the output by tag name.
         """
+
         ASC = 'asc'
         DESC = 'desc'
 
@@ -542,6 +502,7 @@ class CreateTagEnums:
         """
         The type of the tags you want to create. The only allowed value is `access`.
         """
+
         ACCESS = 'access'
 
 
@@ -554,14 +515,17 @@ class DeleteTagAllEnums:
         """
         Select a provider. Supported values are `ghost` and `ims`.
         """
+
         GHOST = 'ghost'
         IMS = 'ims'
+
     class TagType(str, Enum):
         """
         The type of the tag. Supported values are `user`, `service` and `access`.
         `service` and `access` are not supported for IMS resources (`providers` parameter
         set to `ims`).
         """
+
         USER = 'user'
         SERVICE = 'service'
         ACCESS = 'access'
@@ -577,14 +541,17 @@ class DeleteTagEnums:
         Select a provider. Supported values are `ghost` and `ims`. To delete tags both in
         Global Search and Tagging and in IMS, use `ghost,ims`.
         """
+
         GHOST = 'ghost'
         IMS = 'ims'
+
     class TagType(str, Enum):
         """
         The type of the tag. Supported values are `user`, `service` and `access`.
         `service` and `access` are not supported for IMS resources (`providers` parameter
         set to `ims`).
         """
+
         USER = 'user'
         SERVICE = 'service'
         ACCESS = 'access'
@@ -600,6 +567,7 @@ class AttachTagEnums:
         The type of the tag. Supported values are `user`, `service` and `access`.
         `service` and `access` are not supported for IMS resources.
         """
+
         USER = 'user'
         SERVICE = 'service'
         ACCESS = 'access'
@@ -615,6 +583,7 @@ class DetachTagEnums:
         The type of the tag. Supported values are `user`, `service` and `access`.
         `service` and `access` are not supported for IMS resources.
         """
+
         USER = 'user'
         SERVICE = 'service'
         ACCESS = 'access'
@@ -625,7 +594,7 @@ class DetachTagEnums:
 ##############################################################################
 
 
-class CreateTagResults():
+class CreateTagResults:
     """
     Results of a create tag(s) request.
 
@@ -633,9 +602,7 @@ class CreateTagResults():
           an set_tags request.
     """
 
-    def __init__(self,
-                 *,
-                 results: List['CreateTagResultsResultsItem'] = None) -> None:
+    def __init__(self, *, results: List['CreateTagResultsResultsItem'] = None) -> None:
         """
         Initialize a CreateTagResults object.
 
@@ -682,7 +649,8 @@ class CreateTagResults():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class CreateTagResultsResultsItem():
+
+class CreateTagResultsResultsItem:
     """
     CreateTagResultsResultsItem.
 
@@ -690,10 +658,7 @@ class CreateTagResultsResultsItem():
     :attr bool is_error: (optional) true if the tag was not created.
     """
 
-    def __init__(self,
-                 *,
-                 tag_name: str = None,
-                 is_error: bool = None) -> None:
+    def __init__(self, *, tag_name: str = None, is_error: bool = None) -> None:
         """
         Initialize a CreateTagResultsResultsItem object.
 
@@ -745,7 +710,8 @@ class CreateTagResultsResultsItem():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class DeleteTagResults():
+
+class DeleteTagResults:
     """
     Results of a delete_tag request.
 
@@ -753,9 +719,7 @@ class DeleteTagResults():
           delete_tag request.
     """
 
-    def __init__(self,
-                 *,
-                 results: List['DeleteTagResultsItem'] = None) -> None:
+    def __init__(self, *, results: List['DeleteTagResultsItem'] = None) -> None:
         """
         Initialize a DeleteTagResults object.
 
@@ -802,7 +766,8 @@ class DeleteTagResults():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class DeleteTagResultsItem():
+
+class DeleteTagResultsItem:
     """
     Result of a delete_tag request.
 
@@ -814,11 +779,7 @@ class DeleteTagResultsItem():
     # The set of defined properties for the class
     _properties = frozenset(['provider', 'is_error'])
 
-    def __init__(self,
-                 *,
-                 provider: str = None,
-                 is_error: bool = None,
-                 **kwargs) -> None:
+    def __init__(self, *, provider: str = None, is_error: bool = None, **kwargs) -> None:
         """
         Initialize a DeleteTagResultsItem object.
 
@@ -840,7 +801,7 @@ class DeleteTagResultsItem():
             args['provider'] = _dict.get('provider')
         if 'is_error' in _dict:
             args['is_error'] = _dict.get('is_error')
-        args.update({k:v for (k, v) in _dict.items() if k not in cls._properties})
+        args.update({k: v for (k, v) in _dict.items() if k not in cls._properties})
         return cls(**args)
 
     @classmethod
@@ -882,11 +843,12 @@ class DeleteTagResultsItem():
         """
         The provider of the tag.
         """
+
         GHOST = 'ghost'
         IMS = 'ims'
 
 
-class DeleteTagsResult():
+class DeleteTagsResult:
     """
     Results of a deleting unattatched tags.
 
@@ -897,11 +859,9 @@ class DeleteTagsResult():
           results.
     """
 
-    def __init__(self,
-                 *,
-                 total_count: int = None,
-                 errors: bool = None,
-                 items: List['DeleteTagsResultItem'] = None) -> None:
+    def __init__(
+        self, *, total_count: int = None, errors: bool = None, items: List['DeleteTagsResultItem'] = None
+    ) -> None:
         """
         Initialize a DeleteTagsResult object.
 
@@ -962,7 +922,8 @@ class DeleteTagsResult():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class DeleteTagsResultItem():
+
+class DeleteTagsResultItem:
     """
     Result of a delete_tags request.
 
@@ -970,10 +931,7 @@ class DeleteTagsResultItem():
     :attr bool is_error: (optional) true if the tag was not deleted.
     """
 
-    def __init__(self,
-                 *,
-                 tag_name: str = None,
-                 is_error: bool = None) -> None:
+    def __init__(self, *, tag_name: str = None, is_error: bool = None) -> None:
         """
         Initialize a DeleteTagsResultItem object.
 
@@ -1025,7 +983,8 @@ class DeleteTagsResultItem():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class Resource():
+
+class Resource:
     """
     A resource that may have attached tags.
 
@@ -1033,10 +992,7 @@ class Resource():
     :attr str resource_type: (optional) The IMS resource type of the resource.
     """
 
-    def __init__(self,
-                 resource_id: str,
-                 *,
-                 resource_type: str = None) -> None:
+    def __init__(self, resource_id: str, *, resource_type: str = None) -> None:
         """
         Initialize a Resource object.
 
@@ -1090,15 +1046,15 @@ class Resource():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class Tag():
+
+class Tag:
     """
     A tag.
 
     :attr str name: This is the name of the tag.
     """
 
-    def __init__(self,
-                 name: str) -> None:
+    def __init__(self, name: str) -> None:
         """
         Initialize a Tag object.
 
@@ -1146,7 +1102,8 @@ class Tag():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class TagList():
+
+class TagList:
     """
     A list of tags.
 
@@ -1157,12 +1114,9 @@ class TagList():
     :attr List[Tag] items: (optional) Array of output results.
     """
 
-    def __init__(self,
-                 *,
-                 total_count: int = None,
-                 offset: int = None,
-                 limit: int = None,
-                 items: List['Tag'] = None) -> None:
+    def __init__(
+        self, *, total_count: int = None, offset: int = None, limit: int = None, items: List['Tag'] = None
+    ) -> None:
         """
         Initialize a TagList object.
 
@@ -1227,7 +1181,8 @@ class TagList():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class TagResults():
+
+class TagResults:
     """
     Results of an attach_tag or detach_tag request.
 
@@ -1235,9 +1190,7 @@ class TagResults():
           or detach_tag request.
     """
 
-    def __init__(self,
-                 *,
-                 results: List['TagResultsItem'] = None) -> None:
+    def __init__(self, *, results: List['TagResultsItem'] = None) -> None:
         """
         Initialize a TagResults object.
 
@@ -1284,7 +1237,8 @@ class TagResults():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class TagResultsItem():
+
+class TagResultsItem:
     """
     Result of an attach_tag or detach_tag request for a tagged resource.
 
@@ -1293,10 +1247,7 @@ class TagResultsItem():
           error.
     """
 
-    def __init__(self,
-                 resource_id: str,
-                 *,
-                 is_error: bool = None) -> None:
+    def __init__(self, resource_id: str, *, is_error: bool = None) -> None:
         """
         Initialize a TagResultsItem object.
 
