@@ -38,6 +38,7 @@ from .common import get_sdk_headers
 # Service
 ##############################################################################
 
+
 class IamPolicyManagementV1(BaseService):
     """The iam_policy_management V1 service."""
 
@@ -45,23 +46,23 @@ class IamPolicyManagementV1(BaseService):
     DEFAULT_SERVICE_NAME = 'iam_policy_management'
 
     @classmethod
-    def new_instance(cls,
-                     service_name: str = DEFAULT_SERVICE_NAME,
-                    ) -> 'IamPolicyManagementV1':
+    def new_instance(
+        cls,
+        service_name: str = DEFAULT_SERVICE_NAME,
+    ) -> 'IamPolicyManagementV1':
         """
         Return a new client for the iam_policy_management service using the
                specified parameters and external configuration.
         """
         authenticator = get_authenticator_from_environment(service_name)
-        service = cls(
-            authenticator
-            )
+        service = cls(authenticator)
         service.configure_service(service_name)
         return service
 
-    def __init__(self,
-                 authenticator: Authenticator = None,
-                ) -> None:
+    def __init__(
+        self,
+        authenticator: Authenticator = None,
+    ) -> None:
         """
         Construct a new client for the iam_policy_management service.
 
@@ -69,17 +70,14 @@ class IamPolicyManagementV1(BaseService):
                Get up to date information from https://github.com/IBM/python-sdk-core/blob/main/README.md
                about initializing the authenticator of your choice.
         """
-        BaseService.__init__(self,
-                             service_url=self.DEFAULT_SERVICE_URL,
-                             authenticator=authenticator)
-
+        BaseService.__init__(self, service_url=self.DEFAULT_SERVICE_URL, authenticator=authenticator)
 
     #########################
     # Policies
     #########################
 
-
-    def list_policies(self,
+    def list_policies(
+        self,
         account_id: str,
         *,
         accept_language: str = None,
@@ -144,12 +142,10 @@ class IamPolicyManagementV1(BaseService):
 
         if account_id is None:
             raise ValueError('account_id must be provided')
-        headers = {
-            'Accept-Language': accept_language
-        }
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='list_policies')
+        headers = {'Accept-Language': accept_language}
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='list_policies'
+        )
         headers.update(sdk_headers)
 
         params = {
@@ -162,7 +158,7 @@ class IamPolicyManagementV1(BaseService):
             'tag_value': tag_value,
             'sort': sort,
             'format': format,
-            'state': state
+            'state': state,
         }
 
         if 'headers' in kwargs:
@@ -170,16 +166,13 @@ class IamPolicyManagementV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/v1/policies'
-        request = self.prepare_request(method='GET',
-                                       url=url,
-                                       headers=headers,
-                                       params=params)
+        request = self.prepare_request(method='GET', url=url, headers=headers, params=params)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def create_policy(self,
+    def create_policy(
+        self,
         type: str,
         subjects: List['PolicySubject'],
         roles: List['PolicyRole'],
@@ -268,21 +261,13 @@ class IamPolicyManagementV1(BaseService):
         subjects = [convert_model(x) for x in subjects]
         roles = [convert_model(x) for x in roles]
         resources = [convert_model(x) for x in resources]
-        headers = {
-            'Accept-Language': accept_language
-        }
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='create_policy')
+        headers = {'Accept-Language': accept_language}
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='create_policy'
+        )
         headers.update(sdk_headers)
 
-        data = {
-            'type': type,
-            'subjects': subjects,
-            'roles': roles,
-            'resources': resources,
-            'description': description
-        }
+        data = {'type': type, 'subjects': subjects, 'roles': roles, 'resources': resources, 'description': description}
         data = {k: v for (k, v) in data.items() if v is not None}
         data = json.dumps(data)
         headers['content-type'] = 'application/json'
@@ -292,16 +277,13 @@ class IamPolicyManagementV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/v1/policies'
-        request = self.prepare_request(method='POST',
-                                       url=url,
-                                       headers=headers,
-                                       data=data)
+        request = self.prepare_request(method='POST', url=url, headers=headers, data=data)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def update_policy(self,
+    def update_policy(
+        self,
         policy_id: str,
         if_match: str,
         type: str,
@@ -384,21 +366,13 @@ class IamPolicyManagementV1(BaseService):
         subjects = [convert_model(x) for x in subjects]
         roles = [convert_model(x) for x in roles]
         resources = [convert_model(x) for x in resources]
-        headers = {
-            'If-Match': if_match
-        }
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='update_policy')
+        headers = {'If-Match': if_match}
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='update_policy'
+        )
         headers.update(sdk_headers)
 
-        data = {
-            'type': type,
-            'subjects': subjects,
-            'roles': roles,
-            'resources': resources,
-            'description': description
-        }
+        data = {'type': type, 'subjects': subjects, 'roles': roles, 'resources': resources, 'description': description}
         data = {k: v for (k, v) in data.items() if v is not None}
         data = json.dumps(data)
         headers['content-type'] = 'application/json'
@@ -411,19 +385,12 @@ class IamPolicyManagementV1(BaseService):
         path_param_values = self.encode_path_vars(policy_id)
         path_param_dict = dict(zip(path_param_keys, path_param_values))
         url = '/v1/policies/{policy_id}'.format(**path_param_dict)
-        request = self.prepare_request(method='PUT',
-                                       url=url,
-                                       headers=headers,
-                                       data=data)
+        request = self.prepare_request(method='PUT', url=url, headers=headers, data=data)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def get_policy(self,
-        policy_id: str,
-        **kwargs
-    ) -> DetailedResponse:
+    def get_policy(self, policy_id: str, **kwargs) -> DetailedResponse:
         """
         Retrieve a policy by ID.
 
@@ -438,9 +405,9 @@ class IamPolicyManagementV1(BaseService):
         if policy_id is None:
             raise ValueError('policy_id must be provided')
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='get_policy')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='get_policy'
+        )
         headers.update(sdk_headers)
 
         if 'headers' in kwargs:
@@ -451,18 +418,12 @@ class IamPolicyManagementV1(BaseService):
         path_param_values = self.encode_path_vars(policy_id)
         path_param_dict = dict(zip(path_param_keys, path_param_values))
         url = '/v1/policies/{policy_id}'.format(**path_param_dict)
-        request = self.prepare_request(method='GET',
-                                       url=url,
-                                       headers=headers)
+        request = self.prepare_request(method='GET', url=url, headers=headers)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def delete_policy(self,
-        policy_id: str,
-        **kwargs
-    ) -> DetailedResponse:
+    def delete_policy(self, policy_id: str, **kwargs) -> DetailedResponse:
         """
         Delete a policy by ID.
 
@@ -479,9 +440,9 @@ class IamPolicyManagementV1(BaseService):
         if policy_id is None:
             raise ValueError('policy_id must be provided')
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='delete_policy')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='delete_policy'
+        )
         headers.update(sdk_headers)
 
         if 'headers' in kwargs:
@@ -491,21 +452,12 @@ class IamPolicyManagementV1(BaseService):
         path_param_values = self.encode_path_vars(policy_id)
         path_param_dict = dict(zip(path_param_keys, path_param_values))
         url = '/v1/policies/{policy_id}'.format(**path_param_dict)
-        request = self.prepare_request(method='DELETE',
-                                       url=url,
-                                       headers=headers)
+        request = self.prepare_request(method='DELETE', url=url, headers=headers)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def patch_policy(self,
-        policy_id: str,
-        if_match: str,
-        *,
-        state: str = None,
-        **kwargs
-    ) -> DetailedResponse:
+    def patch_policy(self, policy_id: str, if_match: str, *, state: str = None, **kwargs) -> DetailedResponse:
         """
         Restore a deleted policy by ID.
 
@@ -528,17 +480,13 @@ class IamPolicyManagementV1(BaseService):
             raise ValueError('policy_id must be provided')
         if if_match is None:
             raise ValueError('if_match must be provided')
-        headers = {
-            'If-Match': if_match
-        }
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='patch_policy')
+        headers = {'If-Match': if_match}
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='patch_policy'
+        )
         headers.update(sdk_headers)
 
-        data = {
-            'state': state
-        }
+        data = {'state': state}
         data = {k: v for (k, v) in data.items() if v is not None}
         data = json.dumps(data)
         headers['content-type'] = 'application/json'
@@ -551,10 +499,7 @@ class IamPolicyManagementV1(BaseService):
         path_param_values = self.encode_path_vars(policy_id)
         path_param_dict = dict(zip(path_param_keys, path_param_values))
         url = '/v1/policies/{policy_id}'.format(**path_param_dict)
-        request = self.prepare_request(method='PATCH',
-                                       url=url,
-                                       headers=headers,
-                                       data=data)
+        request = self.prepare_request(method='PATCH', url=url, headers=headers, data=data)
 
         response = self.send(request, **kwargs)
         return response
@@ -563,8 +508,8 @@ class IamPolicyManagementV1(BaseService):
     # Roles
     #########################
 
-
-    def list_roles(self,
+    def list_roles(
+        self,
         *,
         accept_language: str = None,
         account_id: str = None,
@@ -606,19 +551,17 @@ class IamPolicyManagementV1(BaseService):
         :rtype: DetailedResponse with `dict` result representing a `RoleList` object
         """
 
-        headers = {
-            'Accept-Language': accept_language
-        }
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='list_roles')
+        headers = {'Accept-Language': accept_language}
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='list_roles'
+        )
         headers.update(sdk_headers)
 
         params = {
             'account_id': account_id,
             'service_name': service_name,
             'source_service_name': source_service_name,
-            'policy_type': policy_type
+            'policy_type': policy_type,
         }
 
         if 'headers' in kwargs:
@@ -626,16 +569,13 @@ class IamPolicyManagementV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/v2/roles'
-        request = self.prepare_request(method='GET',
-                                       url=url,
-                                       headers=headers,
-                                       params=params)
+        request = self.prepare_request(method='GET', url=url, headers=headers, params=params)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def create_role(self,
+    def create_role(
+        self,
         display_name: str,
         actions: List[str],
         name: str,
@@ -692,12 +632,10 @@ class IamPolicyManagementV1(BaseService):
             raise ValueError('account_id must be provided')
         if service_name is None:
             raise ValueError('service_name must be provided')
-        headers = {
-            'Accept-Language': accept_language
-        }
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='create_role')
+        headers = {'Accept-Language': accept_language}
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='create_role'
+        )
         headers.update(sdk_headers)
 
         data = {
@@ -706,7 +644,7 @@ class IamPolicyManagementV1(BaseService):
             'name': name,
             'account_id': account_id,
             'service_name': service_name,
-            'description': description
+            'description': description,
         }
         data = {k: v for (k, v) in data.items() if v is not None}
         data = json.dumps(data)
@@ -717,16 +655,13 @@ class IamPolicyManagementV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/v2/roles'
-        request = self.prepare_request(method='POST',
-                                       url=url,
-                                       headers=headers,
-                                       data=data)
+        request = self.prepare_request(method='POST', url=url, headers=headers, data=data)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def update_role(self,
+    def update_role(
+        self,
         role_id: str,
         if_match: str,
         *,
@@ -761,19 +696,13 @@ class IamPolicyManagementV1(BaseService):
             raise ValueError('role_id must be provided')
         if if_match is None:
             raise ValueError('if_match must be provided')
-        headers = {
-            'If-Match': if_match
-        }
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='update_role')
+        headers = {'If-Match': if_match}
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='update_role'
+        )
         headers.update(sdk_headers)
 
-        data = {
-            'display_name': display_name,
-            'description': description,
-            'actions': actions
-        }
+        data = {'display_name': display_name, 'description': description, 'actions': actions}
         data = {k: v for (k, v) in data.items() if v is not None}
         data = json.dumps(data)
         headers['content-type'] = 'application/json'
@@ -786,19 +715,12 @@ class IamPolicyManagementV1(BaseService):
         path_param_values = self.encode_path_vars(role_id)
         path_param_dict = dict(zip(path_param_keys, path_param_values))
         url = '/v2/roles/{role_id}'.format(**path_param_dict)
-        request = self.prepare_request(method='PUT',
-                                       url=url,
-                                       headers=headers,
-                                       data=data)
+        request = self.prepare_request(method='PUT', url=url, headers=headers, data=data)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def get_role(self,
-        role_id: str,
-        **kwargs
-    ) -> DetailedResponse:
+    def get_role(self, role_id: str, **kwargs) -> DetailedResponse:
         """
         Retrieve a role by ID.
 
@@ -813,9 +735,9 @@ class IamPolicyManagementV1(BaseService):
         if role_id is None:
             raise ValueError('role_id must be provided')
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='get_role')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='get_role'
+        )
         headers.update(sdk_headers)
 
         if 'headers' in kwargs:
@@ -826,18 +748,12 @@ class IamPolicyManagementV1(BaseService):
         path_param_values = self.encode_path_vars(role_id)
         path_param_dict = dict(zip(path_param_keys, path_param_values))
         url = '/v2/roles/{role_id}'.format(**path_param_dict)
-        request = self.prepare_request(method='GET',
-                                       url=url,
-                                       headers=headers)
+        request = self.prepare_request(method='GET', url=url, headers=headers)
 
         response = self.send(request, **kwargs)
         return response
 
-
-    def delete_role(self,
-        role_id: str,
-        **kwargs
-    ) -> DetailedResponse:
+    def delete_role(self, role_id: str, **kwargs) -> DetailedResponse:
         """
         Delete a role by ID.
 
@@ -852,9 +768,9 @@ class IamPolicyManagementV1(BaseService):
         if role_id is None:
             raise ValueError('role_id must be provided')
         headers = {}
-        sdk_headers = get_sdk_headers(service_name=self.DEFAULT_SERVICE_NAME,
-                                      service_version='V1',
-                                      operation_id='delete_role')
+        sdk_headers = get_sdk_headers(
+            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='delete_role'
+        )
         headers.update(sdk_headers)
 
         if 'headers' in kwargs:
@@ -864,9 +780,7 @@ class IamPolicyManagementV1(BaseService):
         path_param_values = self.encode_path_vars(role_id)
         path_param_dict = dict(zip(path_param_keys, path_param_values))
         url = '/v2/roles/{role_id}'.format(**path_param_dict)
-        request = self.prepare_request(method='DELETE',
-                                       url=url,
-                                       headers=headers)
+        request = self.prepare_request(method='DELETE', url=url, headers=headers)
 
         response = self.send(request, **kwargs)
         return response
@@ -881,19 +795,24 @@ class ListPoliciesEnums:
         """
         Optional type of policy.
         """
+
         ACCESS = 'access'
         AUTHORIZATION = 'authorization'
+
     class ServiceType(str, Enum):
         """
         Optional type of service.
         """
+
         SERVICE = 'service'
         PLATFORM_SERVICE = 'platform_service'
+
     class Sort(str, Enum):
         """
         Optional top level policy field to sort results. Ascending sort is default.
         Descending sort available by prepending '-' to field. Example '-last_modified_at'.
         """
+
         ID = 'id'
         TYPE = 'type'
         HREF = 'href'
@@ -902,6 +821,7 @@ class ListPoliciesEnums:
         LAST_MODIFIED_AT = 'last_modified_at'
         LAST_MODIFIED_BY_ID = 'last_modified_by_id'
         STATE = 'state'
+
     class Format(str, Enum):
         """
         Include additional data per policy returned
@@ -910,14 +830,17 @@ class ListPoliciesEnums:
         * `display` - returns the list of all actions included in each of the policy
         roles.
         """
+
         INCLUDE_LAST_PERMIT = 'include_last_permit'
         DISPLAY = 'display'
+
     class State(str, Enum):
         """
         The state of the policy.
         * `active` - returns active policies
         * `deleted` - returns non-active policies.
         """
+
         ACTIVE = 'active'
         DELETED = 'deleted'
 
@@ -927,7 +850,7 @@ class ListPoliciesEnums:
 ##############################################################################
 
 
-class CustomRole():
+class CustomRole:
     """
     An additional set of properties associated with a role.
 
@@ -955,21 +878,23 @@ class CustomRole():
     :attr str href: (optional) The href link back to the role.
     """
 
-    def __init__(self,
-                 *,
-                 id: str = None,
-                 display_name: str = None,
-                 description: str = None,
-                 actions: List[str] = None,
-                 crn: str = None,
-                 name: str = None,
-                 account_id: str = None,
-                 service_name: str = None,
-                 created_at: datetime = None,
-                 created_by_id: str = None,
-                 last_modified_at: datetime = None,
-                 last_modified_by_id: str = None,
-                 href: str = None) -> None:
+    def __init__(
+        self,
+        *,
+        id: str = None,
+        display_name: str = None,
+        description: str = None,
+        actions: List[str] = None,
+        crn: str = None,
+        name: str = None,
+        account_id: str = None,
+        service_name: str = None,
+        created_at: datetime = None,
+        created_by_id: str = None,
+        last_modified_at: datetime = None,
+        last_modified_by_id: str = None,
+        href: str = None
+    ) -> None:
         """
         Initialize a CustomRole object.
 
@@ -1084,7 +1009,8 @@ class CustomRole():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class Policy():
+
+class Policy:
     """
     The core set of properties associated with a policy.
 
@@ -1109,20 +1035,22 @@ class Policy():
     :attr str state: (optional) The policy state.
     """
 
-    def __init__(self,
-                 *,
-                 id: str = None,
-                 type: str = None,
-                 description: str = None,
-                 subjects: List['PolicySubject'] = None,
-                 roles: List['PolicyRole'] = None,
-                 resources: List['PolicyResource'] = None,
-                 href: str = None,
-                 created_at: datetime = None,
-                 created_by_id: str = None,
-                 last_modified_at: datetime = None,
-                 last_modified_by_id: str = None,
-                 state: str = None) -> None:
+    def __init__(
+        self,
+        *,
+        id: str = None,
+        type: str = None,
+        description: str = None,
+        subjects: List['PolicySubject'] = None,
+        roles: List['PolicyRole'] = None,
+        resources: List['PolicyResource'] = None,
+        href: str = None,
+        created_at: datetime = None,
+        created_by_id: str = None,
+        last_modified_at: datetime = None,
+        last_modified_by_id: str = None,
+        state: str = None
+    ) -> None:
         """
         Initialize a Policy object.
 
@@ -1236,20 +1164,19 @@ class Policy():
         """
         The policy state.
         """
+
         ACTIVE = 'active'
         DELETED = 'deleted'
 
 
-class PolicyList():
+class PolicyList:
     """
     A collection of policies.
 
     :attr List[Policy] policies: (optional) List of policies.
     """
 
-    def __init__(self,
-                 *,
-                 policies: List['Policy'] = None) -> None:
+    def __init__(self, *, policies: List['Policy'] = None) -> None:
         """
         Initialize a PolicyList object.
 
@@ -1295,7 +1222,8 @@ class PolicyList():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class PolicyResource():
+
+class PolicyResource:
     """
     The attributes of the resource. Note that only one resource is allowed in a policy.
 
@@ -1304,10 +1232,7 @@ class PolicyResource():
     :attr List[ResourceTag] tags: (optional) List of access management tags.
     """
 
-    def __init__(self,
-                 *,
-                 attributes: List['ResourceAttribute'] = None,
-                 tags: List['ResourceTag'] = None) -> None:
+    def __init__(self, *, attributes: List['ResourceAttribute'] = None, tags: List['ResourceTag'] = None) -> None:
         """
         Initialize a PolicyResource object.
 
@@ -1360,7 +1285,8 @@ class PolicyResource():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class PolicyRole():
+
+class PolicyRole:
     """
     A role associated with a policy.
 
@@ -1370,11 +1296,7 @@ class PolicyRole():
     :attr str description: (optional) The description of the role.
     """
 
-    def __init__(self,
-                 role_id: str,
-                 *,
-                 display_name: str = None,
-                 description: str = None) -> None:
+    def __init__(self, role_id: str, *, display_name: str = None, description: str = None) -> None:
         """
         Initialize a PolicyRole object.
 
@@ -1433,7 +1355,8 @@ class PolicyRole():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class PolicySubject():
+
+class PolicySubject:
     """
     The subject attribute values that must match in order for this policy to apply in a
     permission decision.
@@ -1441,9 +1364,7 @@ class PolicySubject():
     :attr List[SubjectAttribute] attributes: (optional) List of subject attributes.
     """
 
-    def __init__(self,
-                 *,
-                 attributes: List['SubjectAttribute'] = None) -> None:
+    def __init__(self, *, attributes: List['SubjectAttribute'] = None) -> None:
         """
         Initialize a PolicySubject object.
 
@@ -1490,7 +1411,8 @@ class PolicySubject():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class ResourceAttribute():
+
+class ResourceAttribute:
     """
     An attribute associated with a resource.
 
@@ -1499,11 +1421,7 @@ class ResourceAttribute():
     :attr str operator: (optional) The operator of an attribute.
     """
 
-    def __init__(self,
-                 name: str,
-                 value: str,
-                 *,
-                 operator: str = None) -> None:
+    def __init__(self, name: str, value: str, *, operator: str = None) -> None:
         """
         Initialize a ResourceAttribute object.
 
@@ -1565,7 +1483,8 @@ class ResourceAttribute():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class ResourceTag():
+
+class ResourceTag:
     """
     A tag associated with a resource.
 
@@ -1574,11 +1493,7 @@ class ResourceTag():
     :attr str operator: (optional) The operator of an access management tag.
     """
 
-    def __init__(self,
-                 name: str,
-                 value: str,
-                 *,
-                 operator: str = None) -> None:
+    def __init__(self, name: str, value: str, *, operator: str = None) -> None:
         """
         Initialize a ResourceTag object.
 
@@ -1640,7 +1555,8 @@ class ResourceTag():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class Role():
+
+class Role:
     """
     A role resource.
 
@@ -1654,12 +1570,9 @@ class Role():
           'crn:v1:ibmcloud:public:iam-access-management::a/exampleAccountId::customRole:ExampleRoleName'.
     """
 
-    def __init__(self,
-                 *,
-                 display_name: str = None,
-                 description: str = None,
-                 actions: List[str] = None,
-                 crn: str = None) -> None:
+    def __init__(
+        self, *, display_name: str = None, description: str = None, actions: List[str] = None, crn: str = None
+    ) -> None:
         """
         Initialize a Role object.
 
@@ -1725,7 +1638,8 @@ class Role():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class RoleList():
+
+class RoleList:
     """
     A collection of roles returned by the 'list roles' operation.
 
@@ -1734,11 +1648,13 @@ class RoleList():
     :attr List[Role] system_roles: (optional) List of system roles.
     """
 
-    def __init__(self,
-                 *,
-                 custom_roles: List['CustomRole'] = None,
-                 service_roles: List['Role'] = None,
-                 system_roles: List['Role'] = None) -> None:
+    def __init__(
+        self,
+        *,
+        custom_roles: List['CustomRole'] = None,
+        service_roles: List['Role'] = None,
+        system_roles: List['Role'] = None
+    ) -> None:
         """
         Initialize a RoleList object.
 
@@ -1796,7 +1712,8 @@ class RoleList():
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
 
-class SubjectAttribute():
+
+class SubjectAttribute:
     """
     An attribute associated with a subject.
 
@@ -1804,9 +1721,7 @@ class SubjectAttribute():
     :attr str value: The value of an attribute.
     """
 
-    def __init__(self,
-                 name: str,
-                 value: str) -> None:
+    def __init__(self, name: str, value: str) -> None:
         """
         Initialize a SubjectAttribute object.
 
